"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
const request = require("superagent");
const deep_object_diff_1 = require("deep-object-diff");
const Debug = require("debug");
const requests_1 = require("./requests");
const log = Debug('middleware:session');
const THIRTY_DAYS = 1000 * 60 * 60 * 24 * 30;
const defaultOptions = {
    url: 'localhost:3100',
    domain: 'sr.dev',
};
function Session(optionsIn) {
    const options = Object.assign({}, defaultOptions, optionsIn);
    const doPrintDebug = /session-middleware/.test(process.env.DEBUG || '');
    // tslint:disable-next-line:no-console
    const print = (str) => doPrintDebug && console.log(str);
    // Ping auth service
    request
        .get(`${options.url}`)
        .on('error', () => {
        throw new Error("Couldn't reach auth service.");
    })
        .then(response => {
        if (response.text !== 'What are you doing here?') {
            throw new Error(`Auth service responded incorrectly (${response.text}).`);
        }
        print('Auth service responded correctly');
    });
    return async function Middleware(ctx, next) {
        const sid = ctx.cookies.get('sid');
        let session;
        if (sid) {
            log('Found a SID');
            session = await requests_1.getSession(options.url, sid);
        }
        else {
            log("Couldn't find a SID");
            session = await requests_1.createSession(options.url);
        }
        ctx.session = Object.assign({ id: session.id, maxAge: session.maxAge, user: session.user, isLoggedIn: !!session.user, identifier: session.user ? session.user.uuid : session.id }, session.session);
        ctx.cookies.set('sid', session.id, {
            maxAge: THIRTY_DAYS,
            domain: '.' + options.domain,
        });
        await next();
        const _a = ctx.session, { id, maxAge, user, isLoggedIn, identifier } = _a, rest = __rest(_a, ["id", "maxAge", "user", "isLoggedIn", "identifier"]);
        const ctxSession = { id, maxAge, user, session: rest };
        const difference = deep_object_diff_1.diff(session, ctxSession);
        if (Object.keys(difference).length > 0) {
            log('Found difference in session!');
            log(difference);
            await requests_1.updateSession(options.url, id, deep_object_diff_1.diff(session, ctxSession));
        }
    };
}
exports.Session = Session;
//# sourceMappingURL=index.js.map