"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const request = require("superagent");
const Debug = require("debug");
const log = Debug('middleware:session:requests');
async function getSession(url, sid) {
    let response;
    try {
        log(`Trying to get SID:${sid}`);
        response = await request.get(`${url}/api/session/${sid}`);
        log(`Successfully got SID:${sid}`);
    }
    catch (err) {
        response = { body: null, status: err.status || 500 };
    }
    if (response.status === 404) {
        log(`Cound't find SID:${sid}`);
        return createSession(url);
    }
    return response.body;
}
exports.getSession = getSession;
async function createSession(url) {
    let response;
    try {
        log('Creating a new SID');
        response = await request.post(`${url}/api/session`);
        log(`Successfully created new SID: ${response.body.id}`);
    }
    catch (err) {
        response = { body: null };
    }
    return response.body;
}
exports.createSession = createSession;
async function updateSession(url, sid, obj) {
    let response;
    try {
        log(`Trying to update SID:${sid}`);
        response = await request.patch(`${url}/api/session/${sid}`).send(obj);
        log(`Successfully updated SID:${sid}`);
    }
    catch (err) {
        response = { body: null };
    }
    return response.body;
}
exports.updateSession = updateSession;
//# sourceMappingURL=requests.js.map